@@ -55,29 +55,31 @@
 //
 //----------------------------------------------------------------------------
 
-#include <playExr.h>
-#include <ctlToLut.h>
-#include <fileNameForFrame.h>
-#include <FileReadingThread.h>
-#include <osDependent.h>
-#include <ImageBuffers.h>
-#include <Timer.h>
+#include "playExr.h"
+#include "ctlToLut.h"
+#include "fileNameForFrame.h"
+#include "FileReadingThread.h"
+#include "osDependent.h"
+#include "ImageBuffers.h"
+#include "Timer.h"
 #include <ImfThreading.h>
 #include <ImfInputFile.h>
 #include <ImfChannelList.h>
 #include <ImfStandardAttributes.h>
 #include <ImfRgbaYca.h>
 #include <ImfArray.h>
+
 #include <half.h>
 #include <stdlib.h>
 #include <sstream>
 #include <iomanip>
 #include <cmath>
 
-using namespace IlmThread;
-using namespace Imf;
-using namespace Imath;
+
+using namespace OPENEXR_IMF_NAMESPACE;
+using namespace IMATH_NAMESPACE;
 using namespace std;
+using namespace ILMTHREAD_NAMESPACE;
 
 namespace {
 
@@ -405,10 +407,10 @@ const char shaderLuminanceChromaSource[] =
 "                                                                          \n"
 "    Out                                                                   \n"
 "    main (float2 tc: TEXCOORD0,                                           \n"
-"          uniform sampler yImage: TEXUNIT0,                               \n"
-"          uniform sampler ryImage: TEXUNIT1,                              \n"
-"          uniform sampler byImage: TEXUNIT2,                              \n"
-"          uniform sampler lut: TEXUNIT3,                                  \n"
+"          uniform sampler2D yImage: TEXUNIT0,                             \n"
+"          uniform sampler2D ryImage: TEXUNIT1,                            \n"
+"          uniform sampler2D byImage: TEXUNIT2,                            \n"
+"          uniform sampler3D lut: TEXUNIT3,                                \n"
 "          uniform float3 yw,                                              \n"
 "          uniform float expMult,                                          \n"
 "          uniform float videoGamma,                                       \n"
@@ -563,8 +565,8 @@ const char shaderRgbSource[] =
 "                                                                          \n"
 "    Out                                                                   \n"
 "    main (float2 tc: TEXCOORD0,                                           \n"
-"          uniform sampler rgbImage: TEXUNIT0,                             \n"
-"          uniform sampler lut: TEXUNIT3,                                  \n"
+"          uniform sampler2D rgbImage: TEXUNIT0,                           \n"
+"          uniform sampler3D lut: TEXUNIT3,                                \n"
 "          uniform float expMult,                                          \n"
 "          uniform float videoGamma,                                       \n"
 "          uniform float lutMin,                                           \n"
@@ -1002,7 +1004,7 @@ drawStringWithBorder (GLfloat x, GLfloat y, const char str[])
     drawString (x + 1, y + 1, str);
     glLineWidth (2);
     glColor4f (0.8, 0.8, 0.8, 1);
-    drawString (y, y, str);
+    drawString (x, y, str);
     glDisable (GL_LINE_SMOOTH);
     glDisable (GL_BLEND);
 }
@@ -1409,7 +1411,7 @@ playExr (const char fileNameTemplate[],
     // will use internally for OpenEXR file reading.
     //
 
-    Imf::setGlobalThreadCount (numThreads);
+    OPENEXR_IMF_NAMESPACE::setGlobalThreadCount (numThreads);
 
     //
     // Allocate buffers for the images, initialize semaphores
